@@ -69,7 +69,18 @@ if not os.path.isfile(config.SQLITE_PATH):
 ##########################################################################
 class ReverseProxied(object):
     def __init__(self, app):
-        self.app = app
+        # https://werkzeug.palletsprojects.com/en/0.15.x/middleware/proxy_fix/#module-werkzeug.middleware.proxy_fix
+        try:
+            from werkzeug.middleware.proxy_fix import ProxyFix
+            self.app = ProxyFix(app,
+                                x_for=config.PROXY_X_FOR_COUNT,
+                                x_proto=config.PROXY_X_PROTO_COUNT,
+                                x_host=config.PROXY_X_HOST_COUNT,
+                                x_port=config.PROXY_X_PORT_COUNT,
+                                x_prefix=config.PROXY_X_PREFIX_COUNT
+                                )
+        except ImportError:
+            pass
 
     def __call__(self, environ, start_response):
         script_name = environ.get("HTTP_X_SCRIPT_NAME", "")
@@ -95,7 +106,9 @@ if config.DEBUG:
 
 # Create the app!
 app = create_app()
-app.wsgi_app = ReverseProxied(app.wsgi_app)
+
+if config.SERVER_MODE:
+    app.wsgi_app = ReverseProxied(app.wsgi_app)
 
 if config.DEBUG:
     app.debug = True
