@@ -705,18 +705,24 @@ def create_app(app_name=None):
             values.pop(config.APP_VERSION_PARAM)
 
     ##########################################################################
-    # Minify output
+    # Minify output. Not required in desktop mode
     ##########################################################################
-    if not config.DEBUG:
-        from flask_htmlmin import HTMLMIN
-        HTMLMIN(app)
+    if not config.DEBUG and config.SERVER_MODE:
+        from flask_compress import Compress
+        Compress(app)
+
+    from pgadmin.misc.themes import Themes
+    Themes(app)
 
     @app.context_processor
     def inject_blueprint():
-        """Inject a reference to the current blueprint, if any."""
+        """
+        Inject a reference to the current blueprint, if any.
+        """
+
         return {
             'current_app': current_app,
-            'current_blueprint': current_blueprint
+            'current_blueprint': current_blueprint,
         }
 
     @app.errorhandler(Exception)
