@@ -2,9 +2,11 @@
 {% import 'macros/functions/privilege.macros' as PRIVILEGE %}
 {% import 'macros/functions/variable.macros' as VARIABLE %}{% if data %}
 {% set name = o_data.name %}
+{% set exclude_quoting = ['search_path'] %}
 {% if data.name %}
 {% if data.name != o_data.name %}
-ALTER FUNCTION {{ conn|qtIdent(o_data.pronamespace, o_data.name) }}({{o_data.proargtypenames }})
+ALTER FUNCTION {{ conn|qtIdent(o_data.pronamespace, o_data.name) }}({{
+o_data.proargtypenames }})
     RENAME TO {{ conn|qtIdent(data.name) }};
 {% set name = data.name %}
 {% endif %}
@@ -24,9 +26,9 @@ CREATE OR REPLACE FUNCTION {{ conn|qtIdent(o_data.pronamespace, name) }}()
 
     {% if data.procost %}COST {{data.procost}}{% elif o_data.procost %}COST {{o_data.procost}}{% endif %}{% if data.prorows %}
 
-    ROWS {{data.prorows}}{% elif o_data.prorows and o_data.prorows != '0' %}    ROWS {{o_data.prorows}}{% endif -%}{% if data.merged_variables %}{% for v in data.merged_variables %}
+    ROWS {{data.prorows}}{% elif o_data.prorows and o_data.prorows != '0' %}    ROWS {{o_data.prorows}} {%endif -%}{% if data.merged_variables %}{% for v in data.merged_variables %}
 
-    SET {{ conn|qtIdent(v.name) }}={{ v.value|qtLiteral }}{% endfor -%}
+    SET {{ conn|qtIdent(v.name) }}={% if v.name in exclude_quoting %}{{ v.value }}{% else %}{{ v.value|qtLiteral }}{% endif %}{% endfor -%}
     {% endif %}
 
 AS {% if 'probin' in data or 'prosrc_c' in data %}
@@ -35,11 +37,10 @@ $BODY${{ data.prosrc }}$BODY${% elif o_data.lanname == 'c' %}
 {{ o_data.probin|qtLiteral }}, {{ o_data.prosrc_c|qtLiteral }}{% else %}
 $BODY${{ o_data.prosrc }}$BODY${% endif -%};
 {% endif -%}
-
 {% if data.funcowner %}
 
-ALTER FUNCTION {{ conn|qtIdent(o_data.pronamespace, name) }}({{ o_data.proargtypenames }})
-    OWNER TO {{ conn|qtIdent(data.funcowner) }};
+ALTER FUNCTION {{ conn|qtIdent(o_data.pronamespace, name) }}({{o_data.proargtypenames }})
+    OWNER TO {{ data.funcowner }};
 {% endif -%}
 {# The SQL generated below will change priviledges #}
 {% if data.acl %}
@@ -49,7 +50,7 @@ ALTER FUNCTION {{ conn|qtIdent(o_data.pronamespace, name) }}({{ o_data.proargtyp
 {{ PRIVILEGE.UNSETALL(conn, 'FUNCTION', priv.grantee, name, o_data.pronamespace, o_data.proargtypenames) }}
 {% endfor %}
 {% endif -%}
-{% if 'changed' in data.acl %}
+{% if 'changed' in data.datacl %}
 {% for priv in data.acl.changed %}
 
 {{ PRIVILEGE.UNSETALL(conn, 'FUNCTION', priv.grantee, name, o_data.pronamespace, o_data.proargtypenames) }}
@@ -61,18 +62,17 @@ ALTER FUNCTION {{ conn|qtIdent(o_data.pronamespace, name) }}({{ o_data.proargtyp
 {% for priv in data.acl.added %}
 
 {{ PRIVILEGE.SET(conn, 'FUNCTION', priv.grantee, name, priv.without_grant, priv.with_grant, o_data.pronamespace, o_data.proargtypenames) }}
-{% endfor %}
-{% endif %}
+{% endfor %}{% endif -%}
 {% endif -%}
 {% if data.change_func == False %}
 {% if data.variables %}
 {% if 'deleted' in data.variables and data.variables.deleted|length > 0 %}
 
-{{ VARIABLE.UNSET(conn, 'FUNCTION', name, data.variables.deleted, o_data.pronamespace, o_data.proargtypenames ) }}
+{{ VARIABLE.UNSET(conn, 'FUNCTION', name, data.variables.deleted, o_data.pronamespace, o_data.proargtypenames) }}
 {% endif -%}
 {% if 'merged_variables' in data and data.merged_variables|length > 0 %}
 
-{{ VARIABLE.SET(conn, 'FUNCTION', name, data.merged_variables, o_data.pronamespace, o_data.proargtypenames ) }}
+{{ VARIABLE.SET(conn, 'FUNCTION', name, data.merged_variables, o_data.pronamespace, o_data.proargtypenames) }}
 {% endif -%}
 {% endif -%}
 {% endif -%}
@@ -97,12 +97,13 @@ ALTER FUNCTION {{ conn|qtIdent(o_data.pronamespace, name) }}({{ o_data.proargtyp
 {% endif -%}
 {% if data.description is defined and data.description != o_data.description%}
 
-COMMENT ON FUNCTION {{ conn|qtIdent(o_data.pronamespace, name) }}({{ o_data.proargtypenames }})
+COMMENT ON FUNCTION {{ conn|qtIdent(o_data.pronamespace, name) }}({{o_data.proargtypenames }})
     IS {{ data.description|qtLiteral }};
 {% endif -%}
+
 {% if data.pronamespace %}
 
-ALTER FUNCTION {{ conn|qtIdent(o_data.pronamespace, name) }}({{ o_data.proargtypenames }})
+ALTER FUNCTION {{ conn|qtIdent(o_data.pronamespace, name) }}({{o_data.proargtypenames }})
     SET SCHEMA {{ conn|qtIdent(data.pronamespace) }};
 {% endif -%}
 
