@@ -372,9 +372,9 @@ class CompoundTriggerView(PGChildNodeView):
             rset['rows'][0]['oid'],
             tid,
             rset['rows'][0]['name'],
-            icon="icon-compound_trigger" if
-            rset['rows'][0]['is_enable_trigger'] else
-            "icon-compound_trigger-bad"
+            icon="icon-compound_trigger-bad" if
+            rset['rows'][0]['is_enable_trigger'] == 'D' else
+            "icon-compound_trigger"
         )
 
         return make_json_response(
@@ -412,8 +412,9 @@ class CompoundTriggerView(PGChildNodeView):
                     row['oid'],
                     tid,
                     row['name'],
-                    icon="icon-compound_trigger" if row['is_enable_trigger']
-                    else "icon-compound_trigger-bad"
+                    icon="icon-compound_trigger-bad"
+                    if row['is_enable_trigger'] == 'D'
+                    else "icon-compound_trigger"
                 ))
 
         return make_json_response(
@@ -736,9 +737,9 @@ class CompoundTriggerView(PGChildNodeView):
                     new_trid,
                     tid,
                     name,
-                    icon="icon-%s" % self.node_type if
-                    data['is_enable_trigger'] else
-                    "icon-%s-bad" % self.node_type
+                    icon="icon-%s-bad" % self.node_type if
+                    data['is_enable_trigger'] == 'D' else
+                    "icon-%s" % self.node_type
                 )
             )
         except Exception as e:
@@ -889,7 +890,7 @@ class CompoundTriggerView(PGChildNodeView):
         SQL = sql_header + '\n\n' + SQL.strip('\n')
 
         # If compound trigger is disbaled then add sql code for the same
-        if not data['is_enable_trigger']:
+        if data['is_enable_trigger'] != 'O':
             SQL += '\n\n'
             SQL += render_template("/".join([self.template_path,
                                              'enable_disable_trigger.sql']),
@@ -917,7 +918,7 @@ class CompoundTriggerView(PGChildNodeView):
         )
 
         # Convert str 'true' to boolean type
-        is_enable_flag = json.loads(data['enable'])
+        is_enable_trigger = data['is_enable_trigger']
 
         try:
 
@@ -940,7 +941,7 @@ class CompoundTriggerView(PGChildNodeView):
             # current compound trigger which is disabled already so we need to
             # alter the 'is_enable_trigger' flag so that we can render
             # correct SQL for operation
-            o_data['is_enable_trigger'] = is_enable_flag
+            o_data['is_enable_trigger'] = is_enable_trigger
 
             # Adding parent into data dict, will be using it while creating sql
             o_data['schema'] = self.schema
