@@ -300,7 +300,7 @@ define('pgadmin.node.unique_constraint', [
 
               this.stopListening(this.model, 'change:' + name, this.render);
 
-                /*
+              /*
                  * Iterate through all the values, and find out how many are already
                  * present in the collection.
                  */
@@ -315,7 +315,7 @@ define('pgadmin.node.unique_constraint', [
                 }
               });
 
-                /*
+              /*
                  * Adding new values
                  */
 
@@ -330,7 +330,7 @@ define('pgadmin.node.unique_constraint', [
                 collection.add(m);
               });
 
-                /*
+              /*
                  * Removing unwanted!
                  */
               _.each(removed, function(v) {
@@ -377,8 +377,8 @@ define('pgadmin.node.unique_constraint', [
             // If we are in table edit mode then
             if (_.has(m, 'top') && !_.isUndefined(m.top)
               && !m.top.isNew()) {
-                // If OID is undefined then user is trying to add
-                // new constraint which should be allowed for Unique
+              // If OID is undefined then user is trying to add
+              // new constraint which should be allowed for Unique
               return !_.isUndefined(m.get('oid'));
             }
 
@@ -474,8 +474,8 @@ define('pgadmin.node.unique_constraint', [
             // If we are in table edit mode then
             if (_.has(m, 'top') && !_.isUndefined(m.top)
               && !m.top.isNew()) {
-                // If OID is undefined then user is trying to add
-                // new constraint which should be allowed for Unique
+              // If OID is undefined then user is trying to add
+              // new constraint which should be allowed for Unique
               return !_.isUndefined(m.get('oid'));
             }
 
@@ -566,8 +566,8 @@ define('pgadmin.node.unique_constraint', [
             // If we are in table edit mode then
             if (_.has(m, 'top') && !_.isUndefined(m.top)
               && !m.top.isNew()) {
-                // If OID is undefined then user is trying to add
-                // new constraint which should allowed for Unique
+              // If OID is undefined then user is trying to add
+              // new constraint which should allowed for Unique
               return !_.isUndefined(m.get('oid'));
             }
 
@@ -595,8 +595,8 @@ define('pgadmin.node.unique_constraint', [
             // If we are in table edit mode then
             if (_.has(m, 'top') && !_.isUndefined(m.top)
               && !m.top.isNew()) {
-                // If OID is undefined then user is trying to add
-                // new constraint which should allowed for Unique
+              // If OID is undefined then user is trying to add
+              // new constraint which should allowed for Unique
               return !_.isUndefined(m.get('oid'));
             }
 
@@ -629,7 +629,7 @@ define('pgadmin.node.unique_constraint', [
 
           if ((_.isUndefined(index) || String(index).replace(/^\s+|\s+$/g, '') == '') &&
             (_.isUndefined(columns) || _.isNull(columns) || columns.length < 1)) {
-            var msg = gettext('Please specify columns for %(node)s', {node: gettext('Unique constraint')});
+            var msg = gettext('Please specify columns for %s', gettext('Unique constraint'));
             this.errorModel.set('columns', msg);
             return msg;
           }
