@@ -2,9 +2,9 @@ SELECT
     i.indexrelid,
     CASE i.indoption[i.attnum - 1]
     WHEN 0 THEN ARRAY['ASC', 'NULLS LAST']
-    WHEN 1 THEN ARRAY['DESC', 'NULLS FIRST']
+    WHEN 1 THEN ARRAY['DESC', 'NULLS LAST']
     WHEN 2 THEN ARRAY['ASC', 'NULLS FIRST']
-    WHEN 3 THEN ARRAY['DESC', 'NULLS  ']
+    WHEN 3 THEN ARRAY['DESC', 'NULLS FIRST']
     ELSE ARRAY['UNKNOWN OPTION' || i.indoption[i.attnum - 1]::text, '']
     END::text[] AS options,
     i.attnum,
