@@ -200,7 +200,6 @@ class TypeView(PGChildNodeView, DataTypeReader):
         'stats': [{'get': 'statistics'}],
         'dependency': [{'get': 'dependencies'}],
         'dependent': [{'get': 'dependents'}],
-        'module.js': [{}, {}, {'get': 'module_js'}],
         'get_types': [{'get': 'get_types'}, {'get': 'get_types'}],
         'get_stypes': [{'get': 'get_subtypes'}, {'get': 'get_subtypes'}],
         'get_subopclass': [{'get': 'get_subtype_opclass'},
@@ -244,7 +243,7 @@ class TypeView(PGChildNodeView, DataTypeReader):
             ver = self.manager.version
             server_type = self.manager.server_type
             # Set the template path for the SQL scripts
-            self.template_path = 'type/sql/' + (
+            self.template_path = 'types/sql/' + (
                 '#{0}#{1}#'.format(server_type, ver)
                 if server_type == 'gpdb' else
                 '#{0}#'.format(ver)
@@ -930,16 +929,6 @@ class TypeView(PGChildNodeView, DataTypeReader):
                     )
                 )
             # Additional checks goes here
-            # If type is composite then check if it has two members
-            if data and data[arg] == 'c':
-                if len(data['composite']) < 2:
-                    return make_json_response(
-                        status=410,
-                        success=0,
-                        errormsg=gettext(
-                            'Composite types require at least two members.'
-                        )
-                    )
             # If type is range then check if subtype is defined or not
             if data and data[arg] == 'r':
                 if 'typname' not in data or data['typname'] is None:
@@ -1286,11 +1275,6 @@ class TypeView(PGChildNodeView, DataTypeReader):
                     return "-- definition incomplete"
 
             # Additional checks go here
-            # If type is composite then check if it has two members
-            if data and data[arg] == 'c':
-                if len(data['composite']) < 2:
-                    return "-- definition incomplete"
-
             # If type is range then check if subtype is defined or not
             if data and data[arg] == 'r':
                 if 'typname' not in data or data['typname'] is None:
