@@ -9,10 +9,10 @@
 
 define('pgadmin.browser', [
   'sources/tree/tree',
-  'sources/gettext', 'sources/url_for', 'require', 'jquery', 'underscore', 'underscore.string',
+  'sources/gettext', 'sources/url_for', 'require', 'jquery', 'underscore',
   'bootstrap', 'sources/pgadmin', 'pgadmin.alertifyjs', 'bundled_codemirror',
   'sources/check_node_visibility', './toolbar', 'pgadmin.help',
-  'sources/csrf', 'sources/utils', 'pgadmin.browser.utils',
+  'sources/csrf', 'sources/utils', 'sources/window', 'pgadmin.browser.utils',
   'wcdocker', 'jquery.contextmenu', 'jquery.aciplugin', 'jquery.acitree',
   'pgadmin.browser.preferences', 'pgadmin.browser.messages',
   'pgadmin.browser.menu', 'pgadmin.browser.panel', 'pgadmin.browser.layout',
@@ -22,9 +22,9 @@ define('pgadmin.browser', [
   'pgadmin.browser.keyboard', 'sources/tree/pgadmin_tree_save_state',
 ], function(
   tree,
-  gettext, url_for, require, $, _, S,
+  gettext, url_for, require, $, _,
   Bootstrap, pgAdmin, Alertify, codemirror,
-  checkNodeVisibility, toolBar, help, csrfToken, pgadminUtils,
+  checkNodeVisibility, toolBar, help, csrfToken, pgadminUtils, pgWindow
 ) {
   window.jQuery = window.$ = $;
   // Some scripts do export their object in the window only.
@@ -605,7 +605,7 @@ define('pgadmin.browser', [
                 /* OK Button */
                 self.set_master_password(
                   $('#frmMasterPassword #password').val(),
-                  parentDialog.set_callback,
+                  true,parentDialog.set_callback,
                 );
               } else if(event.index == 2) {
                 /* Cancel button */
@@ -677,12 +677,13 @@ define('pgadmin.browser', [
       });
     },
 
-    set_master_password: function(password='', set_callback=()=>{}) {
+    set_master_password: function(password='', button_click=false, set_callback=()=>{}) {
       let data=null, self = this;
 
       if(password != null || password!='') {
         data = JSON.stringify({
           'password': password,
+          'button_click': button_click,
         });
       }
 
@@ -714,8 +715,7 @@ define('pgadmin.browser', [
     bind_beforeunload: function() {
       $(window).on('beforeunload', function(e) {
         /* Can open you in new tab */
-        let openerBrowser = window.opener ?
-          window.opener.pgAdmin.Browser : window.top.pgAdmin.Browser;
+        let openerBrowser = pgWindow.default.pgAdmin.Browser;
 
         let tree_save_interval = pgBrowser.get_preference('browser', 'browser_tree_state_save_interval'),
           confirm_on_refresh_close = openerBrowser.get_preference('browser', 'confirm_on_refresh_close');
@@ -725,7 +725,7 @@ define('pgadmin.browser', [
 
         if(!_.isUndefined(confirm_on_refresh_close) && confirm_on_refresh_close.value) {
           /* This message will not be displayed in Chrome, Firefox, Safari as they have disabled it*/
-          let msg = S(gettext('Are you sure you want to close the %s browser?')).sprintf(pgBrowser.utils.app_name).value();
+          let msg = gettext('Are you sure you want to close the %s browser?', pgBrowser.utils.app_name);
           e.originalEvent.returnValue = msg;
           return msg;
         }
