@@ -8,8 +8,8 @@
 //////////////////////////////////////////////////////////////
 
 define([
-  'underscore', 'underscore.string', 'sources/pgadmin', 'jquery', 'backbone',
-], function(_, S, pgAdmin, $, Backbone) {
+  'underscore', 'sources/pgadmin', 'jquery', 'backbone', 'sources/utils',
+], function(_, pgAdmin, $, Backbone, pgadminUtils) {
   var pgBrowser = pgAdmin.Browser = pgAdmin.Browser || {};
 
   pgBrowser.DataModel = Backbone.Model.extend({
@@ -283,11 +283,17 @@ define([
     },
     // Create a reset function, which allow us to remove the nested object.
     reset: function(opts) {
-      var obj;
+      var obj,
+        reindex = !!(opts && opts.reindex);
 
       if (opts && opts.stop)
         this.stopSession();
 
+      // Let's not touch the child attributes, if reindex is false.
+      if (!reindex) {
+        return;
+      }
+
       for (var id in this.objects) {
         obj = this.get(id);
 
@@ -297,7 +303,7 @@ define([
           } else if (obj instanceof Backbone.Model) {
             obj.clear(opts);
           } else if (obj instanceof pgBrowser.DataCollection) {
-            obj.reset(opts);
+            obj.reset([], opts);
           } else if (obj instanceof Backbone.Collection) {
             obj.each(function(m) {
               if (m instanceof Backbone.DataModel) {
@@ -305,14 +311,11 @@ define([
                 obj.clear(opts);
               }
             });
-            if (!(opts instanceof Array)) {
-              opts = [opts];
-            }
-            Backbone.Collection.prototype.reset.apply(obj, opts);
+            Backbone.Collection.prototype.reset.call(obj, [], opts);
           }
         }
       }
-      this.clear(opts);
+      Backbone.Collection.prototype.reset.apply(this, arguments);
     },
     sessChanged: function() {
       var self = this;
@@ -777,23 +780,23 @@ define([
         max_value = field.max;
 
       if (!_.isUndefined(min_value) && value < min_value) {
-        return S(pgAdmin.Browser.messages.MUST_GR_EQ).sprintf(label, min_value).value();
+        return pgadminUtils.sprintf(pgAdmin.Browser.messages.MUST_GR_EQ, label, min_value);
       } else if (!_.isUndefined(max_value) && value > max_value) {
-        return S(pgAdmin.Browser.messages.MUST_LESS_EQ).sprintf(label, max_value).value();
+        return pgadminUtils.sprintf(pgAdmin.Browser.messages.MUST_LESS_EQ, label, max_value);
       }
       return null;
     },
     number_validate: function(value, field) {
       var pattern = new RegExp('^-?[0-9]+(\.?[0-9]*)?$');
       if (!pattern.test(value)) {
-        return S(pgAdmin.Browser.messages.MUST_BE_NUM).sprintf(field.label).value();
+        return pgadminUtils.sprintf(pgAdmin.Browser.messages.MUST_BE_NUM, field.label);
       }
       return this.check_min_max(value, field);
     },
     integer_validate: function(value, field) {
       var pattern = new RegExp('^-?[0-9]*$');
       if (!pattern.test(value)) {
-        return S(pgAdmin.Browser.messages.MUST_BE_INT).sprintf(field.label).value();
+        return pgadminUtils.sprintf(pgAdmin.Browser.messages.MUST_BE_INT, field.label);
       }
       return this.check_min_max(value, field);
     },
@@ -996,7 +999,7 @@ define([
     },
     // Override the reset function, so that - we can reset the model
     // properly.
-    reset: function(opts) {
+    reset: function(_set, opts) {
       if (opts && opts.stop)
         this.stopSession();
       this.each(function(m) {
