@@ -9,13 +9,13 @@
 
 define('pgadmin.browser.node', [
   'sources/tree/pgadmin_tree_node', 'sources/url_for',
-  'sources/gettext', 'jquery', 'underscore', 'underscore.string', 'sources/pgadmin',
+  'sources/gettext', 'jquery', 'underscore', 'sources/pgadmin',
   'pgadmin.browser.menu', 'backbone', 'pgadmin.alertifyjs', 'pgadmin.browser.datamodel',
   'backform', 'sources/browser/generate_url', 'pgadmin.help', 'sources/utils',
   'pgadmin.browser.utils', 'pgadmin.backform',
 ], function(
   pgadminTreeNode, url_for,
-  gettext, $, _, S, pgAdmin,
+  gettext, $, _, pgAdmin,
   Menu, Backbone, Alertify, pgBrowser,
   Backform, generateUrl, help,
   commonUtils
@@ -28,6 +28,10 @@ define('pgadmin.browser.node', [
       F1: 112,
     };
 
+  const REMOVE_SERVER_PRIORITY = 5;
+  const REMOVE_SERVER_LABEL = 'Remove Server';
+  const SERVER = 'server';
+
   // It has already been defined.
   // Avoid running this script again.
   if (pgBrowser.Node)
@@ -142,8 +146,8 @@ define('pgadmin.browser.node', [
           module: self,
           applies: ['object', 'context'],
           callback: 'delete_obj',
-          priority: 2,
-          label: gettext('Delete/Drop'),
+          priority: self.get_menu_item_priority(self.type, 2),
+          label: self.change_menu_label(self.type, gettext('Delete/Drop')),
           data: {
             'url': 'drop',
           },
@@ -203,9 +207,7 @@ define('pgadmin.browser.node', [
         // For each script type create menu
         _.each(self.hasScriptTypes, function(stype) {
 
-          var type_label = S(
-            gettext('%s Script')
-          ).sprintf(stype.toUpperCase()).value();
+          var type_label = gettext('%s Script',stype.toUpperCase());
 
           stype = stype.toLowerCase();
 
@@ -435,9 +437,8 @@ define('pgadmin.browser.node', [
                   )) {
                     Alertify.pgNotifier(
                       options.textStatus, xhr,
-                      S(
-                        gettext('Error retrieving properties - %s')
-                      ).sprintf(options.errorThrown || _label).value(), function(msg) {
+                      gettext('Error retrieving properties - %s', options.errorThrown || _label),
+                      function(msg) {
                         if(msg === 'CRYPTKEY_SET') {
                           fetchAjaxHook();
                         } else {
@@ -672,8 +673,7 @@ define('pgadmin.browser.node', [
           if (!d)
             return;
 
-          l = S(gettext('Create - %s')).sprintf(
-            [this.label]).value();
+          l = gettext('Create - %s', this.label);
           p = addPanel();
 
           setTimeout(function() {
@@ -696,7 +696,7 @@ define('pgadmin.browser.node', [
 
               Alertify.confirm(
                 gettext('Edit in progress?'),
-                S(msg).sprintf(o.label.toLowerCase(), d.label).value(),
+                commonUtils.sprintf(msg, o.label.toLowerCase(), d.label),
                 function() {
                   setTimeout(function() {
                     o.showProperties(i, d, p, args.action);
@@ -746,31 +746,44 @@ define('pgadmin.browser.node', [
         var msg, title;
         if (input.url == 'delete') {
 
-          msg = S(gettext('Are you sure you want to drop %s "%s" and all the objects that depend on it?'))
-            .sprintf(obj.label.toLowerCase(), d.label).value();
-          title = S(gettext('DROP CASCADE %s?')).sprintf(obj.label).value();
+          msg = gettext('Are you sure you want to drop %s "%s" and all the objects that depend on it?',
+            obj.label.toLowerCase(), d.label);
+          title = gettext('DROP CASCADE %s?', obj.label);
 
           if (!(_.isFunction(obj.canDropCascade) ?
             obj.canDropCascade.apply(obj, [d, i]) : obj.canDropCascade)) {
             Alertify.error(
-              S(gettext('The %s "%s" cannot be dropped.'))
-                .sprintf(obj.label, d.label).value(),
+              gettext('The %s "%s" cannot be dropped.', obj.label, d.label),
               10
             );
             return;
           }
         } else {
-          msg = S(gettext('Are you sure you want to drop %s "%s"?'))
-            .sprintf(obj.label.toLowerCase(), d.label).value();
-          title = S(gettext('DROP %s?')).sprintf(obj.label).value();
+          var remove_drop_text;
+          if(obj.type === SERVER) {
+            remove_drop_text = 'Remove';
+          }
+          else {
+            remove_drop_text = 'DROP';
+          }
+
+          msg = gettext('Are you sure you want to %s %s "%s"?', remove_drop_text.toLowerCase(), obj.label.toLowerCase(), d.label);
+          title = gettext('%s %s?', remove_drop_text, obj.label);
 
           if (!(_.isFunction(obj.canDrop) ?
             obj.canDrop.apply(obj, [d, i]) : obj.canDrop)) {
-            Alertify.error(
-              S(gettext('The %s "%s" cannot be dropped.'))
-                .sprintf(obj.label, d.label).value(),
-              10
-            );
+            if(obj.type === SERVER) {
+              Alertify.error(
+                gettext('The %s "%s" cannot be removed.', obj.label, d.label),
+                10
+              );
+            }
+            else {
+              Alertify.error(
+                gettext('The %s "%s" cannot be dropped.', obj.label, d.label),
+                10
+              );
+            }
             return;
           }
         }
@@ -799,10 +812,14 @@ define('pgadmin.browser.node', [
                     console.warn(e.stack || e);
                   }
                 }
-                pgBrowser.report_error(
-                  S(gettext('Error dropping %s: "%s"'))
-                    .sprintf(obj.label, objName)
-                    .value(), msg);
+                if(obj.type === SERVER) {
+                  pgBrowser.report_error(
+                    gettext('Error removing %s: "%s"', obj.label, objName), msg);
+                }
+                else {
+                  pgBrowser.report_error(
+                    gettext('Error dropping %s: "%s"', obj.label, objName), msg);
+                }
               });
           },
           null).show();
@@ -1042,7 +1059,8 @@ define('pgadmin.browser.node', [
         j = panel.$container.find('.obj_properties').first(),
         view = j.data('obj-view'),
         content = $('<div tabindex="1"></div>')
-          .addClass('pg-prop-content col-12');
+          .addClass('pg-prop-content col-12'),
+        confirm_close = true;
 
       // Handle key press events for Cancel, save and help button
       var handleKeyDown = function(event, context) {
@@ -1051,7 +1069,7 @@ define('pgadmin.browser.node', [
 
         switch (event.which) {
         case keyCode.ESCAPE:
-          closePanel();
+          closePanel(true);
           break;
         case keyCode.ENTER:
           // Return if event is fired from child element
@@ -1249,6 +1267,39 @@ define('pgadmin.browser.node', [
           window.open(that.dialogHelp, 'pgadmin_help');
         }.bind(panel),
 
+        warnBeforeChangesLost = function(warn_text, yes_callback) {
+          var j = this.$container.find('.obj_properties').first(),
+            view = j && j.data('obj-view'),
+            self = this;
+
+          let confirm_on_properties_close = pgBrowser.get_preferences_for_module('browser').confirm_on_properties_close;
+          if (confirm_on_properties_close && confirm_close && view && view.model) {
+            if(view.model.sessChanged()){
+              Alertify.confirm(
+                gettext('Warning'),
+                warn_text,
+                function() {
+                  setTimeout(function(){
+                    yes_callback();
+                  }.bind(self), 50);
+                  return true;
+                },
+                function() {
+                  return true;
+                }
+              ).set('labels', {
+                ok: gettext('Yes'),
+                cancel: gettext('No'),
+              }).show();
+            } else {
+              return true;
+            }
+          } else {
+            yes_callback();
+            return true;
+          }
+        }.bind(panel),
+
         onSave = function(view, saveBtn) {
           var m = view.model,
             d = m.toJSON(true),
@@ -1409,7 +1460,7 @@ define('pgadmin.browser.node', [
                 btn.on('click',() => {
                   // Removing the action-mode
                   panel.$container.removeAttr('action-mode');
-                  onCancelFunc.call(arguments);
+                  onCancelFunc.call(true);
                 });
               },
             }, {
@@ -1421,9 +1472,15 @@ define('pgadmin.browser.node', [
               disabled: true,
               register: function(btn) {
                 btn.on('click',() => {
-                  setTimeout(function() {
-                    editFunc.call();
-                  }, 0);
+                  warnBeforeChangesLost.call(
+                    panel,
+                    gettext('Changes will be lost. Are you sure you want to reset?'),
+                    function() {
+                      setTimeout(function() {
+                        editFunc.call();
+                      }, 0);
+                    }
+                  );
                 });
               },
             }, {
@@ -1464,7 +1521,10 @@ define('pgadmin.browser.node', [
           // Show contents before buttons
           j.prepend(content);
         }.bind(panel),
-        closePanel = function() {
+        closePanel = function(confirm_close_flag) {
+          if(!_.isUndefined(confirm_close_flag)) {
+            confirm_close = confirm_close_flag;
+          }
           // Closing this panel
           this.close();
         }.bind(panel),
@@ -1493,7 +1553,7 @@ define('pgadmin.browser.node', [
               },
             }
           );
-          closePanel();
+          closePanel(false);
         },
         saveNewNode = function(that) {
           var panel = this,
@@ -1512,7 +1572,7 @@ define('pgadmin.browser.node', [
           } catch (e) {
             console.warn(e.stack || e);
           }
-          closePanel();
+          closePanel(false);
         }.bind(panel, that),
         editInNewPanel = function() {
           // Open edit in separate panel
@@ -1544,6 +1604,15 @@ define('pgadmin.browser.node', [
         onEdit = editInNewPanel.bind(panel);
       }
       if (panel.closeable()) {
+        panel.on(wcDocker.EVENT.CLOSING, warnBeforeChangesLost.bind(
+          panel,
+          gettext('Changes will be lost. Are you sure you want to close the dialog?'),
+          function() {
+            panel.off(wcDocker.EVENT.CLOSING);
+            panel.close();
+          }
+        ));
+
         var onCloseFunc = function() {
           var j = this.$container.find('.obj_properties').first(),
             view = j && j.data('obj-view');
@@ -1659,7 +1728,7 @@ define('pgadmin.browser.node', [
         )), function(o) {
           return o.priority;
         }), function(o) {
-          hash = S('%s/%s').sprintf(hash, encodeURI(o._id)).value();
+          hash = commonUtils.sprintf('%s/%s', hash, encodeURI(o._id));
         });
       }
 
@@ -1714,6 +1783,18 @@ define('pgadmin.browser.node', [
         return this.parent_type;
       }
     },
+    get_menu_item_priority: function(type, default_priority) { //downgrade Remove Server priority in menus only for Servers
+      if(type && type === SERVER) {
+        return REMOVE_SERVER_PRIORITY;
+      }
+      return default_priority;
+    },
+    change_menu_label: function(type, default_label) { //change Delete/Drop menu option to Remove Server
+      if(type && type === SERVER) {
+        return gettext(REMOVE_SERVER_LABEL);
+      }
+      return default_label;
+    },
   });
 
   return pgAdmin.Browser.Node;
