@@ -161,6 +161,8 @@ define([
 
           // compare as usual
           if (l === r) return 0;
+          else if (l === null && r != null) return -1;
+          else if (l != null && r === null) return 1;
           else if (l < r) return -1;
           return 1;
         }
@@ -1890,7 +1892,8 @@ define([
     },
   });
 
-  Backgrid.BooleanCellFormatter = _.extend(Backgrid.CellFormatter.prototype, {
+  var BooleanCellFormatter = Backgrid.BooleanCellFormatter = function() {};
+  _.extend(BooleanCellFormatter.prototype, {
     fromRaw: function (rawValue) {
       if (_.isUndefined(rawValue) || _.isNull(rawValue)) {
         return false;
