@@ -9,7 +9,7 @@
 
 import {calculateQueryRunTime} from './calculate_query_run_time';
 import gettext from '../gettext';
-import {sprintf} from 'sprintf-js';
+import {sprintf} from 'sources/utils';
 
 function hasResultsToDisplay(res) {
   return res.colinfo != null;
@@ -40,7 +40,7 @@ export function callRenderAfterPoll(sqlEditor, alertify, res) {
       res.result += '\n\n' + msg;
     else
       res.result = msg;
-    sqlEditor.update_msg_history(true, res.result, true);
+    sqlEditor.update_msg_history(true, res.result, false);
     sqlEditor.reset_data_store();
     if (isNotificationEnabled(sqlEditor)) {
       alertify.success(msg, sqlEditor.info_notifier_timeout);
