@@ -8,7 +8,7 @@
 //////////////////////////////////////////////////////////////
 
 import gettext from '../../../../static/js/gettext';
-import {sprintf} from 'sprintf-js';
+import {sprintf} from 'sources/utils';
 import Backform from '../../../../static/js/backform.pgadmin';
 import {Dialog} from '../../../../static/js/alertify/dialog';
 import url_for from 'sources/url_for';
