@@ -399,26 +399,10 @@ def poll(trans_id):
                 additional_messages = ''.join(messages)
             notifies = conn.get_notifies()
 
-            # Procedure/Function output may comes in the form of Notices
-            # from the database server, so we need to append those outputs
-            # with the original result.
-            if result is None:
-                result = conn.status_message()
-                if (result != 'SELECT 1' or result != 'SELECT 0') and \
-                   result is not None and additional_messages:
-                    result = additional_messages + result
-                else:
-                    result = None
-
             if st:
                 if 'primary_keys' in session_obj:
                     primary_keys = session_obj['primary_keys']
 
-                if 'has_oids' in session_obj:
-                    has_oids = session_obj['has_oids']
-                    if has_oids:
-                        oids = {'oid': 'oid'}
-
                 # Fetch column information
                 columns_info = conn.get_column_info()
                 client_primary_key = generate_client_primary_key_name(
@@ -429,48 +413,34 @@ def poll(trans_id):
                 # If trans_obj is a QueryToolCommand then check for updatable
                 # resultsets and primary keys
                 if isinstance(trans_obj, QueryToolCommand):
-                    trans_obj.check_updatable_results_pkeys()
-                    pk_names, primary_keys = trans_obj.get_primary_keys()
-                    # If primary_keys exist, add them to the session_obj to
-                    # allow for saving any changes to the data
-                    if primary_keys is not None:
-                        session_obj['primary_keys'] = primary_keys
+                    if trans_obj.check_updatable_results_pkeys_oids():
+                        pk_names, primary_keys = trans_obj.get_primary_keys()
+                        session_obj['has_oids'] = trans_obj.has_oids()
+                        # Update command_obj in session obj
+                        session_obj['command_obj'] = pickle.dumps(
+                            trans_obj, -1)
+                        # If primary_keys exist, add them to the session_obj to
+                        # allow for saving any changes to the data
+                        if primary_keys is not None:
+                            session_obj['primary_keys'] = primary_keys
+
+                if 'has_oids' in session_obj:
+                    has_oids = session_obj['has_oids']
+                    if has_oids:
+                        oids = {'oid': 'oid'}
 
                 if columns_info is not None:
-                    # If it is a QueryToolCommand that has obj_id attribute
-                    # then it should also be editable
-                    if hasattr(trans_obj, 'obj_id') and \
-                        (not isinstance(trans_obj, QueryToolCommand) or
-                         trans_obj.can_edit()):
-                        # Get the template path for the column
-                        template_path = 'columns/sql/#{0}#'.format(
-                            conn.manager.version
-                        )
+                    # Only QueryToolCommand or TableCommand can be editable
+                    if hasattr(trans_obj, 'obj_id') and trans_obj.can_edit():
+                        columns = trans_obj.get_columns_types(conn)
 
-                        SQL = render_template(
-                            "/".join([template_path, 'nodes.sql']),
-                            tid=trans_obj.obj_id,
-                            has_oids=True
-                        )
-                        # rows with attribute not_null
-                        colst, rset = conn.execute_2darray(SQL)
-                        if not colst:
-                            return internal_server_error(errormsg=rset)
-
-                    for key, col in enumerate(columns_info):
-                        col_type = dict()
-                        col_type['type_code'] = col['type_code']
-                        col_type['type_name'] = None
-                        col_type['internal_size'] = col['internal_size']
-                        columns[col['name']] = col_type
-
-                        if rset:
-                            col_type['not_null'] = col['not_null'] = \
-                                rset['rows'][key]['not_null']
-
-                            col_type['has_default_val'] = \
-                                col['has_default_val'] = \
-                                rset['rows'][key]['has_default_val']
+                    else:
+                        for col in columns_info:
+                            col_type = dict()
+                            col_type['type_code'] = col['type_code']
+                            col_type['type_name'] = None
+                            col_type['internal_size'] = col['internal_size']
+                            columns[col['name']] = col_type
 
                 if columns:
                     st, types = fetch_pg_types(columns, trans_obj)
@@ -492,6 +462,7 @@ def poll(trans_id):
                         col_info['pgadmin_alias'] = \
                             re.sub("[%()]+", "|", col_name)
                     session_obj['columns_info'] = columns
+
                 # status of async_fetchmany_2darray is True and result is none
                 # means nothing to fetch
                 if result and rows_affected > -1:
@@ -512,6 +483,17 @@ def poll(trans_id):
                 # restore it and update the session variable.
                 update_session_grid_transaction(trans_id, session_obj)
 
+            # Procedure/Function output may comes in the form of Notices
+            # from the database server, so we need to append those outputs
+            # with the original result.
+            if result is None:
+                result = conn.status_message()
+                if result is not None and additional_messages is not None:
+                    result = additional_messages + result
+                else:
+                    result = result if result is not None \
+                        else additional_messages
+
         elif status == ASYNC_EXECUTION_ABORTED:
             status = 'Cancel'
         else:
@@ -691,7 +673,7 @@ def generate_client_primary_key_name(columns_info):
 @login_required
 def save(trans_id):
     """
-    This method is used to save the changes to the server
+    This method is used to save the data changes to the server
 
     Args:
         trans_id: unique transaction id
@@ -741,7 +723,7 @@ def save(trans_id):
                 return make_json_response(
                     data={'status': status, 'result': u"{}".format(msg)}
                 )
-        status, res, query_res, _rowid = trans_obj.save(
+        status, res, query_results, _rowid = trans_obj.save(
             changed_data,
             session_obj['columns_info'],
             session_obj['client_primary_key'],
@@ -749,7 +731,7 @@ def save(trans_id):
     else:
         status = False
         res = error_msg
-        query_res = None
+        query_results = None
         _rowid = None
 
     transaction_status = conn.transaction_status()
@@ -758,7 +740,7 @@ def save(trans_id):
         data={
             'status': status,
             'result': res,
-            'query_result': query_res,
+            'query_results': query_results,
             '_rowid': _rowid,
             'transaction_status': transaction_status
         }
